==> moodle-1.4.3-pgsql.tgz: moodle/lang/cs/install.php <==
<?PHP // $Id$ 
      // install.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004100800)


$string['admindirerror'] = 'Adres sprvy (admin) nen uren sprvn';
$string['admindirname'] = 'Adres sprvy (admin)';
$string['admindirsetting'] = 'Velmi mal mnostv webovch hostitel pouv /admin jako speciln URL k pstupu ke kontrolnmu panelu nebo k podobnm funkcm. To bohuel zpsobuje konflikty se standardnm umstnm adrese sprvy v Moodle. Tento konflikt mete vyeit pejmenovnm adrese sprvy va instalace. Vlote sem nov nzev, nap. <br/> <br /><b>moodleadmin</b><br /> <br />Tm se oprav odkazy na sprvu Moodle.';
$string['caution'] = 'Varovn';
$string['chooselanguage'] = 'Vyberte jazyk';
$string['compatibilitysettings'] = 'Kontrola nastaven vaeho PHP...';
$string['configfilenotwritten'] = 'Instalan skript nemohl automaticky vytvoit soubor config.php s va konfigurac - pravdpodobn z dvod nastaven prv k zpisu do adrese Moodle. Mete run zkoprovat nsledujc kd do souboru s nzvem config.php v hlavnm adresi va instalace Moodle.';
$string['configfilewritten'] = 'config.php byl spn vytvoen';
$string['configurationcomplete'] = 'Konfigurace hotov';
$string['database'] = 'Databze';
$string['databasesettings'] = 'Nyn muste nakonfigurovat spojen k databzi, kde si bude Moodle ukldat sv data. Tato databze mus ji existovat, stejn jako mus bt nastaveno uivatelsk jmno a heslo pro pstup k n.<br/>
<br /> <br />
<b>Typ:</b> mysql nebo postgres7<br />
<b>Hostitel:</b> nap. localhost nebo db.naseskola.cz<br />
<b>Nzev:</b> nzev databze, nap. moodle<br />
<b>Uivatel:</b> uivatelsk jmno tu pro pstup k databzi<br />
<b>Heslo:</b> heslo k tomuto tu<br />
<b>Pedpona tabulek:</b> voliteln pedpona, kter se vlo ped nzvy vech tabulek (umouje mt jednu databzi pro vce instalac Moodle)';
$string['dataroot'] = 'Datov adres';
$string['datarooterror'] = 'Vmi specifikovan datov adres nebyl nalezen a nemohl bt vytvoen. Bu opravte vloenou cestu, nebo vytvote adres run.';
$string['dbconnectionerror'] = 'Nemu se spojit s databz, kterou jste specifikovali. Prosm, zkontrolujte nastaven databze.';
$string['dbcreationerror'] = 'Chyba pi vytven databze. Nelze vytvoit databzi danho jmna s poskytnutm nastavenm';
$string['dbhost'] = 'Hostitelsk server';
$string['dbpass'] = 'Heslo';
$string['dbprefix'] = 'Pedpona tabulek';
$string['dbtype'] = 'Typ';
$string['directorysettings'] = '<p>Prosm, potvrte umstn tto Moodle instalace.</p>

<p><b>Webov adresa:</b>
Urete plnou webovou adresu, na ni bude v Moodle dostupn. Jsou-li vae strnky dostupn pes vce URL, vyberte z nich tu, kterou budou pouvat vai studenti. Na konci adresy nevkldejte lomtko.</p>

<p><b>Moodle adres:</b>
Urtete plnou cestu k adresi s touto instalac. Ujistte se, e vm odpovdaj mal/VELK psmena.</p>

<p><b>Datov adres:</b>
Je teba mt diskov prostor, kam me Moodle ukldat nahran (uploadovan) soubory. K tomuto adresi mus mt proces webovho serveru prvo ke ten I ZPISU (webov server bv spoutn pod uivatelem \'nobody\' nebo \'apache\' nebo nco podobnho). Tento adres by neml bt dostupn pmo pes webov rozhran (me obsahovat neveejn data).</p>';
$string['dirroot'] = 'Moodle adres';
$string['dirrooterror'] = 'Hodnota \'Moodle adres\' nevypad nastaven sprvn - nemu tam najt Moodle instalaci. Nsledujc hodnota byla resetovna.';
$string['download'] = 'Sthnout';
$string['fail'] = 'Selhalo';
$string['fileuploads'] = 'Nahran soubory (uploads)';
$string['fileuploadserror'] = 'Mlo by bt zapnuto';
$string['fileuploadshelp'] = '<p>Vypad to, e na vaem serveru nen umonno nahrvat soubory.</p>

<p>Moodle me bt i pesto nainstalovn, ale bez tto funkce nebudete moci nahrvat dn soubory (nap. studijn materily nebo fotografie uivatel).</p>

<p>Chcete-li povolit nahrvn soubor, budete muset vy (nebo v sprvce) upravit hlavn soubor php.ini na vaem serveru a zmnit nastaven
<b>file_uploads</b> na \'1\'.</p>';
$string['gdversion'] = 'Verze GD';
$string['gdversionerror'] = 'Knihovna GD je potebn ke zpracovvn a tvorb obrzk (nap. fotografie, grafy apod.)';
$string['gdversionhelp'] = '<p>Vypad to, e na vaem serveru nen nainstalovna knihovna GD.</p>

<p>GD je knihovna, kterou vyaduje PHP, aby umonilo Moodlu zpracovvat obrzky (jako jsou ikony uivatel) a vytvet nov obrzky (jako jsou nap. grafy pstup na vae strnky). Moodle bude fungovat i bez GD, ale tyto funkce nebudou dostupn.</p>

<p>Chcete-li pidat GD do PHP pod Unixem, zkompilujte PHP s parametrem --with-gd .</p>

<p>Pod systmem Windows sta vtinou upravit php.ini a odkomentovat dek odkazujc na libgd.dll.</p>';
$string['installation'] = 'Instalace';
$string['magicquotesruntime'] = 'Magic Quotes Run Time';
$string['magicquotesruntimeerror'] = 'Mlo by bt vypnuto';
$string['magicquotesruntimehelp'] = '<p>Funkce \'Magic quotes runtime\' by mla bt vypnuta pro sprvn fungovn Moodlu.</p>

<p>Normln bv tato funkce implicitn vypnut ... podvejte se na nastaven <b>magic_quotes_runtime</b> ve vaem php.ini .</p>

<p>Pokud nemte pstup k vaemu php.ini, mete zkusit umstit nsledujc dek do souboru  .htaccess ve vaem Moodle adresi:
<blockquote>php_value magic_quotes_runtime Off</blockquote>
</p>';
$string['memorylimit'] = 'Limit pamti';
$string['memorylimiterror'] = 'Limit pamti pro PHP skripty je nastaven relativn nzko ... pozdji vs to me stt problmy.';
$string['memorylimithelp'] = '<p>Limit pamti pro PHP skripty je na vaem serveru momentln nastaven na hodnotu $a.</p>

<p>Toto me pozdji zpsobovat Moodlu problmy, zvlt pi vtm mnostv modul a/nebo uivatel.</p>

<p>Je-li to mon, doporuujeme vm nakonfigurovat PHP s vym limitem - nap. 16M. Je nkolik zpsob, kter mete zkusit:
<ol>
<li>Mete-li, pekompilujte PHP s volbou <i>--enable-memory-limit</i>.
Toto umon Moodlu nastavit si pro sebe poadovan limit.
<li>Mte-li pstup k vaemu souboru php.ini, zmte nastaven <b>memory_limit</b>
na hodnotu blzkou 16M. Nemte-li takov prva, podejte vaeho sprvce webovho serveru, aby to pro vs udlal.
<li>Na nkterch PHP serverech mete v Moodle adresi vytvoit soubor .htaccess s nsledujcm dkem:
<p><blockquote>php_value memory_limit 16M</blockquote></p>
<p>Bohuel, na nkterch serverech tmto vyadte z provozu <b>vechny</b> PHP strnky (pi jejich prohlen uvidte chybov zprvy), take budete muset soubor .htaccess odstranit.
</ol>';
$string['mysqlextensionisnotpresentinphp'] = 'PHP nebylo korektn nakonfigurovno pro komunikaci v MySQL. Zkontrolujte v php.ini nebo pekompilujte PHP.';
$string['pass'] = 'Prolo';
$string['phpversion'] = 'Verze PHP';
$string['phpversionerror'] = 'Verze PHP mus bt alespo 4.1.0 nebo vy';
$string['phpversionhelp'] = '<p>Moodle vyaduje verzi PHP alespo 4.1.0.</p>
<p>Vae stvajc PHP m verzi $a</p>
<p>Muste upgradovat vae PHP nebo Moodle nainstalovat na hostitele s vy verz!</p>';
$string['safemode'] = 'Bezpen reim (safe mode)';
$string['safemodeerror'] = 'Moodle me mt problmy pi zapnutm bezpenm reimu (safe mode)';
$string['safemodehelp'] = '<p>Moodle me mt mnostv problm pi zapnutm bezpenm reimu PHP (tzv. safe mode). Jednm z nich je, e pravdpodobn nebude moci vytvet nov soubory.</p>

<p>Bezpen reim bv zapnut u paranoidnch veejnch webovch hostitel, take mon bude stait najt si jinho hostitele pro v Moodle.</p>

<p>Mete zkusit pokraovat v instalaci, ale oekvejte mon problmy.</p>';
$string['sessionautostart'] = 'Session Auto Start';
$string['sessionautostarterror'] = 'Mlo by bt vypnuto';
$string['sessionautostarthelp'] = '<p>Moodle poaduje podporu session a nebude bez n fungovat.</p>

<p>Podporu session mete povolit v souboru php.ini  ... podvejte se na parametr session.auto_start .</p>';
$string['wwwroot'] = 'Webov adresa';
$string['wwwrooterror'] = 'Toto nevypad jako platn webov adresa tto instalace Moodle.';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/cs/install.php <==
<?PHP // $Id$ 
      // install.php - created with Moodle 1.5.2 + (2005060223)


$string['admindirerror'] = 'Adres sprvy (admin) nen uren sprvn';
$string['admindirname'] = 'Adres sprvy (admin)';
$string['admindirsetting'] = 'Velmi mal mnostv webovch hostitel pouv /admin jako speciln URL k pstupu ke kontrolnmu panelu nebo k podobnm funkcm. To bohuel zpsobuje konflikty se standardnm umstnm adrese sprvy v Moodle. Tento konflikt mete vyeit pejmenovnm adrese sprvy va instalace. Vlote sem nov nzev, nap. <br/> <br /><b>moodleadmin</b><br /> <br />Tm se oprav odkazy na sprvu Moodle.';
$string['caution'] = 'Varovn';
$string['chooselanguage'] = 'Vyberte jazyk';
$string['compatibilitysettings'] = 'Kontrola nastaven vaeho PHP...';
$string['configfilenotwritten'] = 'Instalan skript nemohl automaticky vytvoit soubor config.php s va konfigurac - pravdpodobn z dvod nastaven prv k zpisu do adrese Moodle. Mete run zkoprovat nsledujc kd do souboru s nzvem config.php v hlavnm adresi va instalace Moodle.';
$string['configfilewritten'] = 'config.php byl spn vytvoen';
$string['configurationcomplete'] = 'Konfigurace hotov';
$string['database'] = 'Databze';
$string['databasecreationsettings'] = 'Nyn muste nakonfigurovat spojen k databzi, kde si bude Moodle ukldat vtinu svch dat. Tato databze bude vytvoena automaticky instalanm programem Moodle4Windows s nsledujcm nastavenm.<br/>
<br /> <br />
<b>Typ:</b>instaltor nastav na \"mysql\"<br />
<b>Hostitel:</b>instaltor nastav na \"localhost\"<br />
<b>Nzev:</b> nzev databze, nap. moodle<br />
<b>Uivatel:</b>instaltor nastav na \"root\"<br />
<b>Heslo:</b> heslo k tomuto tu<br />
<b>Pedpona tabulek:</b> voliteln pedpona, kter se vlo ped nzvy vech tabulek (umouje mt jednu databzi pro vce instalac Moodle)';
$string['databasesettings'] = 'Nyn muste nakonfigurovat spojen k databzi, kde si bude Moodle ukldat vtinu svch dat. Tato databze mus ji existovat, stejn jako mus bt nastaveno uivatelsk jmno a heslo pro pstup k n.<br/>
<br /> <br />
<b>Typ:</b> mysql nebo postgres7<br />
<b>Hostitel:</b> nap. localhost nebo db.naseskola.cz<br />
<b>Nzev:</b> nzev databze, nap. moodle<br />
<b>Uivatel:</b> uivatelsk jmno tu pro pstup k databzi<br />
<b>Heslo:</b> heslo k tomuto tu<br />
<b>Pedpona tabulek:</b> voliteln pedpona, kter se vlo ped nzvy vech tabulek (umouje mt jednu databzi pro vce instalac Moodle)';
$string['dataroot'] = 'Datov adres';
$string['datarooterror'] = 'Vmi specifikovan datov adres nebyl nalezen a nemohl bt vytvoen. Bu opravte vloenou cestu, nebo vytvote adres run.';
$string['dbconnectionerror'] = 'Nemu se spojit s databz, kterou jste specifikovali. Prosm, zkontrolujte nastaven databze.';
$string['dbcreationerror'] = 'Chyba pi vytven databze. Nelze vytvoit databzi danho jmna s poskytnutm nastavenm';
$string['dbhost'] = 'Hostitelsk server';
$string['dbpass'] = 'Heslo';
$string['dbprefix'] = 'Pedpona tabulek';
$string['dbtype'] = 'Typ';
$string['directorysettings'] = '<p>Prosm, potvrte umstn tto Moodle instalace.</p>

<p><b>Webov adresa:</b>
Urete plnou webovou adresu, na ni bude v Moodle dostupn. Jsou-li vae strnky dostupn pes vce URL, vyberte z nich tu, kterou budou pouvat vai studenti. Na konci adresy nevkldejte lomtko.</p>

<p><b>Moodle adres:</b>
Urtete plnou cestu k adresi s touto instalac. Ujistte se, e vm odpovdaj mal/VELK psmena.</p>

<p><b>Datov adres:</b>
Je teba mt diskov prostor, kam me Moodle ukldat nahran (uploadovan) soubory. K tomuto adresi mus mt proces webovho serveru prvo ke ten I ZPISU (webov server bv spoutn pod uivatelem \'nobody\' nebo \'apache\' nebo nco podobnho). Tento adres by neml bt dostupn pmo pes webov rozhran (me obsahovat neveejn data).</p>';
$string['dirroot'] = 'Moodle adres';
$string['dirrooterror'] = 'Hodnota \'Moodle adres\' nevypad nastaven sprvn - nemu tam najt Moodle instalaci. Nsledujc hodnota byla resetovna.';
$string['download'] = 'Sthnout';
$string['fail'] = 'Selhalo';
$string['fileuploads'] = 'Nahran soubory (uploads)';
$string['fileuploadserror'] = 'Mlo by bt zapnuto';
$string['fileuploadshelp'] = '<p>Vypad to, e na vaem serveru nen umonno nahrvat soubory.</p>

<p>Moodle me bt i pesto nainstalovn, ale bez tto funkce nebudete moci nahrvat dn soubory (nap. studijn materily nebo fotografie uivatel).</p>

<p>Chcete-li povolit nahrvn soubor, budete muset vy (nebo v sprvce) upravit hlavn soubor php.ini na vaem serveru a zmnit nastaven
<b>file_uploads</b> na \'1\'.</p>';
$string['gdversion'] = 'Verze GD';
$string['gdversionerror'] = 'Knihovna GD je potebn ke zpracovvn a tvorb obrzk (nap. fotografie, grafy apod.)';
$string['gdversionhelp'] = '<p>Vypad to, e na vaem serveru nen nainstalovna knihovna GD.</p>

<p>GD je knihovna, kterou vyaduje PHP, aby umonilo Moodlu zpracovvat obrzky (jako jsou ikony uivatel) a vytvet nov obrzky (jako jsou nap. grafy pstup na vae strnky). Moodle bude fungovat i bez GD, ale tyto funkce nebudou dostupn.</p>

<p>Chcete-li pidat GD do PHP pod Unixem, zkompilujte PHP s parametrem --with-gd .</p>

<p>Pod systmem Windows sta vtinou upravit php.ini a odkomentovat dek odkazujc na libgd.dll.</p>';
$string['installation'] = 'Instalace';
$string['magicquotesruntime'] = 'Magic Quotes Run Time';
$string['magicquotesruntimeerror'] = 'Mlo by bt vypnuto';
$string['magicquotesruntimehelp'] = '<p>Funkce \'Magic quotes runtime\' by mla bt vypnuta pro sprvn fungovn Moodlu.</p>

<p>Normln bv tato funkce implicitn vypnut ... podvejte se na nastaven <b>magic_quotes_runtime</b> ve vaem php.ini .</p>

<p>Pokud nemte pstup k vaemu php.ini, mete zkusit umstit nsledujc dek do souboru  .htaccess ve vaem Moodle adresi:
<blockquote>php_value magic_quotes_runtime Off</blockquote>
</p>';
$string['memorylimit'] = 'Limit pamti';
$string['memorylimiterror'] = 'Limit pamti pro PHP skripty je nastaven relativn nzko ... pozdji vs to me stt problmy.';
$string['memorylimithelp'] = '<p>Limit pamti pro PHP skripty je na vaem serveru momentln nastaven na hodnotu $a.</p>

<p>Toto me pozdji zpsobovat Moodlu problmy, zvlt pi vtm mnostv modul a/nebo uivatel.</p>

<p>Je-li to mon, doporuujeme vm nakonfigurovat PHP s vym limitem - nap. 16M. Je nkolik zpsob, kter mete zkusit:
<ol>
<li>Mete-li, pekompilujte PHP s volbou <i>--enable-memory-limit</i>.
Toto umon Moodlu nastavit si pro sebe poadovan limit.</li>
<li>Mte-li pstup k vaemu souboru php.ini, zmte nastaven <b>memory_limit</b>
na hodnotu blzkou 16M. Nemte-li takov prva, podejte vaeho sprvce webovho serveru, aby to pro vs udlal.</li>
<li>Na nkterch PHP serverech mete v Moodle adresi vytvoit soubor .htaccess s nsledujcm dkem:
<p><blockquote>php_value memory_limit 16M</blockquote></p>
<p>Bohuel, na nkterch serverech tmto vyadte z provozu <b>vechny</b> PHP strnky (pi jejich prohlen uvidte chybov zprvy), take budete muset soubor .htaccess odstranit.</li>
</ol>';
$string['mysqlextensionisnotpresentinphp'] = 'PHP nebylo korektn nakonfigurovno pro komunikaci v MySQL. Zkontrolujte v php.ini nebo pekompilujte PHP.';
$string['pass'] = 'Prolo';
$string['phpversion'] = 'Verze PHP';
$string['phpversionerror'] = 'Verze PHP mus bt alespo 4.1.0 nebo vy';
$string['phpversionhelp'] = '<p>Moodle vyaduje verzi PHP alespo 4.1.0.</p>
<p>Vae stvajc PHP m verzi $a</p>
<p>Muste upgradovat vae PHP nebo Moodle nainstalovat na hostitele s vy verz!</p>';
$string['safemode'] = 'Bezpen reim (safe mode)';
$string['safemodeerror'] = 'Moodle me mt problmy pi zapnutm bezpenm reimu (safe mode)';
$string['safemodehelp'] = '<p>Moodle me mt mnostv problm pi zapnutm bezpenm reimu PHP (tzv. safe mode). Jednm z nich je, e pravdpodobn nebude moci vytvet nov soubory.</p>

<p>Bezpen reim bv zapnut u paranoidnch veejnch webovch hostitel, take mon bude stait najt si jinho hostitele pro v Moodle.</p>

<p>Mete zkusit pokraovat v instalaci, ale oekvejte mon problmy.</p>';
$string['sessionautostart'] = 'Session Auto Start';
$string['sessionautostarterror'] = 'Mlo by bt vypnuto';
$string['sessionautostarthelp'] = '<p>Moodle poaduje podporu session a nebude bez n fungovat.</p>

<p>Podporu session mete povolit v souboru php.ini  ... podvejte se na parametr session.auto_start .</p>';
$string['wwwroot'] = 'Webov adresa';
$string['wwwrooterror'] = 'Toto nevypad jako platn webov adresa tto instalace Moodle.';

?>
